@@ -181,7 +181,8 @@ class TestMol(unittest.TestCase):
                       if len(output_block.find_mmcif_category(name)) > 0]
         common_categories = [name for name in cnames_out if name in cnames]
         common_categories.sort()
-        cc = ['_atom_site.', '_atom_type.', '_cell.', '_chem_comp.',
+        cc = ['_atom_site.', '_atom_type.', '_audit_author.',
+              '_cell.', '_chem_comp.',
               '_diffrn.', '_diffrn_detector.', '_diffrn_radiation.',
               '_diffrn_source.',
               '_entity.', '_entity_poly_seq.', '_entry.',
@@ -376,6 +377,8 @@ class TestMol(unittest.TestCase):
         self.assertAlmostEqual(st.cell.a, 34.77)
         self.assertEqual(st.cell.alpha, 90)
         self.assertEqual(len(st.ncs), 0)
+        self.assertEqual(st.meta.authors,
+                         ['ALBRIGHT, R.A.', 'MOSSING, M.C.', 'MATTHEWS, B.W.'])
         model = st[0]
         self.assertEqual(len(model), 1)
         self.assertEqual(len(model.subchains()), 2)
